@@ -48,11 +48,14 @@
 
 #define PR_AF_INET6 24  /* same as AF_INET6 */
 
+#ifndef HAVE_LONG_LONG
+#define HAVE_LONG_LONG
+#endif
+
 #if defined(__i386__) || defined(__arm__)
 
 #define IS_LITTLE_ENDIAN 1
 #undef  IS_BIG_ENDIAN
-#define	HAVE_LONG_LONG
 #undef	HAVE_ALIGNED_DOUBLES
 #undef	HAVE_ALIGNED_LONGLONGS
 
@@ -140,7 +143,6 @@
 #define PR_BYTES_PER_WORD_LOG2  3
 #define PR_BYTES_PER_DWORD_LOG2 3
 
-#define HAVE_LONG_LONG
 #define HAVE_ALIGNED_DOUBLES
 #define HAVE_ALIGNED_LONGLONGS
 
@@ -148,7 +150,6 @@
 
 #undef  IS_LITTLE_ENDIAN
 #define IS_BIG_ENDIAN 1
-#define HAVE_LONG_LONG
 #define HAVE_ALIGNED_DOUBLES
 #define HAVE_ALIGNED_LONGLONGS
 #define IS_64
@@ -196,7 +197,6 @@
 
 #undef IS_LITTLE_ENDIAN
 #define  IS_BIG_ENDIAN 1
-#define HAVE_LONG_LONG
 #define  HAVE_ALIGNED_DOUBLES
 #define  HAVE_ALIGNED_LONGLONGS
 
@@ -241,7 +241,6 @@
 #elif defined(__alpha__)
 #define IS_LITTLE_ENDIAN 1
 #undef  IS_BIG_ENDIAN
-#define	HAVE_LONG_LONG
 #define	HAVE_ALIGNED_DOUBLES
 #define	HAVE_ALIGNED_LONGLONGS
 #define IS_64
@@ -289,7 +288,6 @@
 
 #undef  IS_LITTLE_ENDIAN
 #define IS_BIG_ENDIAN    1
-#define	HAVE_LONG_LONG
 #undef	HAVE_ALIGNED_DOUBLES
 #undef	HAVE_ALIGNED_LONGLONGS
 
